/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "uimenu.h"
#include "util/memory.h"
#include "assert/assert.h"
#include "input.h"

void uiMenuInit(
  uimenu_t *menu,
  const uint8_t columns,
  const uint8_t rows
) {
  assertNotNull(menu, "Menu cannot be NULL.");

  memoryZero(menu, sizeof(uimenu_t));

  menu->columns = columns;
  menu->rows = rows;
}

void uiMenuSetCursor(
  uimenu_t *menu,
  const uint8_t x,
  const uint8_t y
) {
  assertNotNull(menu, "Menu cannot be NULL.");
  assert(x < menu->columns, "X position out of bounds.");
  assert(y < menu->rows, "Y position out of bounds.");

  menu->x = x;
  menu->y = y;
}

void uiMenuMoveCursor(
  uimenu_t *menu,
  const int8_t x,
  const int8_t y
) {
  assertNotNull(menu, "Menu cannot be NULL.");
  uiMenuSetCursor(
    menu,
    (menu->x + x) % menu->columns,
    (menu->y + y) % menu->rows
  );
}

uimenuaction_t uiMenuUpdate(uimenu_t *menu) {
  assertNotNull(menu, "Menu cannot be NULL.");

}