/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "dusk.h"

typedef enum {
  UI_MENU_ACTION_NOTHING,
  UI_MENU_ACTION_CURSOR_MOVE,
  UI_MENU_ACTION_CURSOR_ACCEPT,
  UI_MENU_ACTION_CURSOR_CANCEL
} uimenuaction_t;

typedef struct {
  uint8_t columns;
  uint8_t rows;
  uint8_t x;
  uint8_t y;
} uimenu_t;

/**
 * Initializes a menu.
 * 
 * @param menu The menu to initialize.
 * @param columns The amount of columns in the menu.
 * @param rows The amount of rows in the menu.
 */
void uiMenuInit(
  uimenu_t *menu,
  const uint8_t columns,
  const uint8_t rows
);

/**
 * Sets the cursor of a menu.
 * 
 * @param menu The menu to set the cursor of.
 * @param x The x position of the cursor.
 * @param y The y position of the cursor.
 */
void uiMenuSetCursor(
  uimenu_t *menu,
  const uint8_t x,
  const uint8_t y
);

/**
 * Moves the cursor of a menu.
 * 
 * @param menu The menu to move the cursor of.
 * @param x The amount to move the cursor on the x axis.
 * @param y The amount to move the cursor on the y axis.
 */
void uiMenuMoveCursor(
  uimenu_t *menu,
  const int8_t x,
  const int8_t y
);

/**
 * Handles updating of a menu, this will accept input basically.
 * 
 * @param menu The menu to update.
 */
uimenuaction_t uiMenuUpdate(uimenu_t *menu);